@@ -1,4 +1,4 @@
-#########v1.2.3#########
+#########v1.2.5#########
 import urllib.request
 from urllib.request import Request
 
@@ -30,4 +30,4 @@ class requesthandler:
                 self.validResponse = True
 
         except: 
-            self.networkError = False
\ No newline at end of file
+            self.networkError = True
\ No newline at end of file
